package com.community.huiju.controller;

import com.community.commom.constant.Constant;
import com.community.commom.mode.ResponseBean;
import com.community.commom.redis.RedisTemplate;
import com.community.commom.session.UserElement;
import com.community.huiju.common.wxpay.HfWxConfig;
import com.community.huiju.common.wxpay.WXPay;
import com.community.huiju.service.TaVistorServiceI;
import com.community.huiju.service.WxPayServiceI;
import com.google.common.collect.Maps;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.cloud.context.config.annotation.RefreshScope;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import javax.servlet.http.HttpSession;
import java.util.HashMap;
import java.util.Map;

/**
 * @author FXF
 * @date 2019-02-19
 */
@RestController
@RefreshScope
@RequestMapping("/")
@Api(value = "微信支付 API", description = "微信支付 API")
public class WxPayController {
	private Logger log = LoggerFactory.getLogger(WxPayController.class);
	
	@Autowired
	private WxPayServiceI wxPayService;
	
	@ApiOperation(value = "统一下单", notes = "统一下单")
	@ApiImplicitParams({ @ApiImplicitParam(paramType = "path", dataType = "Integer", name = "billInvoiceId", value = "账单Id"),
			@ApiImplicitParam(paramType = "header",dataType = "String",name = "X-Auth-Token",value = "Token") })
	@RequestMapping(value = "/wxUnifiedOrder/{billInvoiceId}",method = RequestMethod.GET)
	public ResponseBean wxUnifiedOrder(@PathVariable("billInvoiceId") Integer billInvoiceId, HttpSession session){
		ResponseBean responseBean = new ResponseBean();
		UserElement userElement = (UserElement) session.getAttribute(Constant.APP_USER_SESSION);
		
		Map<String, String> resp = Maps.newHashMap();
		try {
			resp = wxPayService.wxUnifiedOrder(billInvoiceId,userElement);
		} catch (Exception e) {
			e.printStackTrace();
			responseBean.addError(e.getMessage());
			return responseBean;
		}
		log.info("调用微信支付参数: {}",resp);
		responseBean.addSuccess(resp);
		return responseBean;
	}
	
	@ApiOperation(value = "下载对账单", notes = "下载对账单")
	@RequestMapping(value = "/wxDownloadBill",method = RequestMethod.GET)
	public ResponseBean wxDownloadBill(){
		ResponseBean responseBean = new ResponseBean();
		
		Map<String, String> resp = Maps.newHashMap();
		try {
			resp = wxPayService.wxDownloadBill();
		} catch (Exception e) {
			e.printStackTrace();
		}
		responseBean.addSuccess(resp);
		return responseBean;
	}
	
	@ApiOperation(value = "订单查询", notes = "订单查询")
	@RequestMapping(value = "/wxOrderQuery",method = RequestMethod.GET)
	public ResponseBean wxOrderQuery(){
		ResponseBean responseBean = new ResponseBean();
		Map<String, String> resp = Maps.newHashMap();
		try {
			resp = wxPayService.wxOrderQuery();
		} catch (Exception e) {
			e.printStackTrace();
			responseBean.addError("查询失败");
			return responseBean;
		}
		responseBean.addSuccess(resp);
		return responseBean;
	}
}
