package com.community.huiju.service.impl;

import com.community.commom.session.UserElement;
import com.community.huiju.common.wxpay.HfWxConfig;
import com.community.huiju.common.wxpay.WXPay;
import com.community.huiju.common.wxpay.WXPayConstants;
import com.community.huiju.common.wxpay.WXPayUtil;
import com.community.huiju.controller.WxPayController;
import com.community.huiju.dao.TpBillInvoiceMapper;
import com.community.huiju.model.TpBillInvoice;
import com.community.huiju.service.WxPayServiceI;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.time.Instant;
import java.util.HashMap;
import java.util.Map;

/**
 * @author FXF
 * @date 2018-10-25
 */
@Service("wxPayService")
public class WxPayServiceImpl implements WxPayServiceI {
	private Logger log = LoggerFactory.getLogger(WxPayServiceImpl.class);
	
	@Autowired
	private TpBillInvoiceMapper tpBillInvoiceMapper;
	
	/**
	 * 微信支付统一下单
	 *
	 * @return
	 * @param billInvoiceId
	 * @param userElement
	 */
	@Override
	public Map<String, String> wxUnifiedOrder(Integer billInvoiceId, UserElement userElement) throws Exception {
		HfWxConfig config = new HfWxConfig();
		WXPay wxpay = new WXPay(config);
		
		//获取支付金额
		TpBillInvoice tpBillInvoice = tpBillInvoiceMapper.selectByIdAndUserId(billInvoiceId,userElement.getId(),userElement.getCommunityId());
		
		if (null == tpBillInvoice){
			throw new Exception("订单不存在");
		}
		
		Map<String, String> data = new HashMap<String, String>();
		data.put("body", "支付测试");
		//商品号唯一
		data.put("out_trade_no", String.valueOf(System.currentTimeMillis()));
		data.put("device_info", "");
		data.put("fee_type", "CNY");
		//金额 后台计算
		data.put("total_fee", String.valueOf(tpBillInvoice.getPayPrice()));
		//终端IP
		data.put("spbill_create_ip", "123.12.12.123");
		//回调地址
		data.put("notify_url", "http://106.14.20.193:8086/app-api/wxDownloadBill");
		// 此处指定为APP支付
		data.put("trade_type", "APP");
		Map<String, String> resp = wxpay.unifiedOrder(data);
		log.info("下单成功：{}", resp);
		
		//第二次重新生成签名
		Map<String, String> secondSignData = new HashMap<String, String>();
		long timestamp = Instant.now().getEpochSecond();
		secondSignData.put("appid", config.getAppID());
		secondSignData.put("partnerid", config.getMchID());
		secondSignData.put("prepayid", resp.get("prepay_id"));
		secondSignData.put("noncestr", resp.get("nonce_str"));
		secondSignData.put("timestamp", String.valueOf(timestamp));
		secondSignData.put("package", "Sign=WXPay");
		secondSignData.put("sign", WXPayUtil.generateSignature(secondSignData, config.getKey(), WXPayConstants.SignType.MD5));
		return secondSignData;
	}
	
	/**
	 * 下载对账单
	 *
	 * @return
	 */
	@Override
	public Map<String, String> wxDownloadBill() throws Exception {
		HfWxConfig config = new HfWxConfig();
		WXPay wxpay = new WXPay(config);
		
		Map<String, String> data = new HashMap<String, String>();
		data.put("bill_date", "20190219");
		data.put("bill_type", "ALL");
		return wxpay.downloadBill(data);
	}
	
	/**
	 * 订单查询
	 *
	 * @return
	 */
	@Override
	public Map<String, String> wxOrderQuery() throws Exception {
		HfWxConfig config = new HfWxConfig();
		WXPay wxpay = new WXPay(config);
		
		Map<String, String> data = new HashMap<String, String>();
		data.put("out_trade_no", "2019021910595900000012");
		return wxpay.orderQuery(data);
	}
}
